@@ -15,4 +15,6 @@ suite = unittest.TestLoader().loadTestsFromNames(
     ]
 )
     
-unittest.TextTestRunner(verbosity=1).run(suite)
+testresult = unittest.TextTestRunner(verbosity=1).run(suite)
+sys.exit(0 if testresult.wasSuccessful() else 1)
+
